==> 2.1.2-dev.tar.gz: lib/NetmeraPushInbox.dart <==
import 'dart:convert';

import 'package:netmera_flutter_sdk/NetmeraInteractiveAction.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class NetmeraPushInbox {
  String? _title;
  String? _subtitle;
  String? _body;
  int? _pushType;
  String? _pushId;
  String? _pushInstanceId;
  String? _sendDate;
  int? _inboxStatus;
  String? _actionDeepLinkUrl;
  String? _actionWebPageUrl;
  String? _externalId;
  String? _mediaAttachmentURL;
  String? _expireTime;
  List<dynamic>? _categories;
  List<NetmeraInteractiveAction>? _interactiveActions;
  Map<dynamic, dynamic>? _customJson;
  Map<dynamic, dynamic>? _pushAction;
  List<dynamic>? _carousel;
  String? _category;

  String? getCategory() => _category;

  setCategory(String value) {
    _category = value;
  }

  Map<dynamic, dynamic>? getCustomJson() => _customJson;

  setCustomJson(Map<dynamic, dynamic> value) {
    _customJson = value;
  }

  Map<dynamic, dynamic>? getPushAction() => _pushAction;

  setPushAction(Map<dynamic, dynamic> value) {
    _pushAction = value;
  }

  List<dynamic>? getCarousel() => _carousel;

  setCarousel(List<dynamic> value) {
    _carousel = value;
  }

  String? getTitle() => _title;

  setTitle(String value) {
    _title = value;
  }

  String? getPopUpExpirationTime() => _expireTime;

  setPopUpExpirationTime(String value) {
    _expireTime = value;
  }

  String? getMediaAttachmentUrl() => _mediaAttachmentURL;

  setTMediaAttachmentUrl(String value) {
    _mediaAttachmentURL = value;
  }

  String? getSubtitle() => _subtitle;

  List<dynamic>? getCategories() => _categories;

  setCategories(List<dynamic> value) {
    _categories = value;
  }

  List<NetmeraInteractiveAction>? getInteractiveActions() => _interactiveActions;

  setInteractiveActions(List<NetmeraInteractiveAction> value) {
    _interactiveActions = value;
  }

  String? getExternalId() => _externalId;

  setExternalId(String value) {
    _externalId = value;
  }

  String? getDeepLink() => _actionDeepLinkUrl;

  setDeepLink(String value) {
    _actionDeepLinkUrl = value;
  }

  String? getWebPage() => _actionWebPageUrl;

  setWebPage(String value) {
    _actionWebPageUrl = value;
  }

  int? getInboxStatus() => _inboxStatus;

  setInboxStatus(int value) {
    _inboxStatus = value;
  }

  String? getSendDate() => _sendDate;

  setSendDate(String value) {
    _sendDate = value;
  }

  String? getPushInstanceId() => _pushInstanceId;

  setPushInstanceId(String value) {
    _pushInstanceId = value;
  }

  String? getPushId() => _pushId;

  setPushId(String value) {
    _pushId = value;
  }

  int? getPushType() => _pushType;

  setPushType(int value) {
    _pushType = value;
  }

  String? getBody() => _body;

  setBody(String value) {
    _body = value;
  }

  setSubtitle(String value) {
    _subtitle = value;
  }

  static fromJson(Map<dynamic, dynamic> json) {
    NetmeraPushInbox inbox = new NetmeraPushInbox();
    inbox._title = json['title'];
    inbox._subtitle = json['subtitle'];
    inbox._body = json['body'];
    inbox._pushType = json['pushType'];
    inbox._pushId = json['pushId'];
    inbox._pushInstanceId = json['pushInstanceId'];
    inbox._sendDate = json['sendDate'];
    inbox._inboxStatus = json['inboxStatus'];
    inbox._actionDeepLinkUrl = json['action_deeplink_url'];
    inbox._actionWebPageUrl = json['action_webpage_url'];
    inbox._externalId = json['externalId'];
    inbox._customJson = json['customJson'];
    inbox._pushAction = json['pushAction'];
    inbox._carousel = json['carousel'];
    inbox._mediaAttachmentURL = json['mediaAttachmentURL'];
    inbox._category = json['category'];
    inbox._categories = json['categories'];
    inbox._expireTime = json['expireTime'];
    if (json['interactiveActions'] != null) {
      inbox._interactiveActions =
          List.from(jsonDecode(json['interactiveActions']))
              .map((model) => NetmeraInteractiveAction.fromJson(model))
              .toList(); //todo check flutter 2.0
    }

    return inbox;
  }

  Map<String, dynamic> toJson() => {
        'title': _title,
        'subtitle': _subtitle,
        'body': _body,
        'pushType': _pushType,
        'pushId': _pushId,
        'pushInstanceId': _pushInstanceId,
        'sendDate': _sendDate,
        'inboxStatus': _inboxStatus,
        'action_deeplink_url': _actionDeepLinkUrl,
        'action_webpage_url': _actionWebPageUrl,
        'externalId': _externalId,
        'customJson': _customJson,
        'pushAction': _pushAction,
        'carousel': _carousel,
        'mediaAttachmentURL': _mediaAttachmentURL,
        'category': _category,
        'categories': _categories,
        'interactiveActions': _interactiveActions,
        'expireTime': _expireTime
      };
}

==> 2.1.4-dev.tar.gz: lib/NetmeraPushInbox.dart <==
import 'dart:convert';

import 'package:netmera_flutter_sdk/NetmeraInteractiveAction.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class NetmeraPushInbox {
  String? _title;
  String? _subtitle;
  String? _body;
  int? _pushType;
  String? _pushId;
  String? _pushInstanceId;
  String? _sendDate;
  int? _inboxStatus;
  String? _actionDeepLinkUrl;
  String? _actionWebPageUrl;
  String? _externalId;
  String? _mediaAttachmentURL;
  String? _expireTime;
  List<dynamic>? _categories;
  List<NetmeraInteractiveAction>? _interactiveActions;
  Map<dynamic, dynamic>? _customJson;
  Map<dynamic, dynamic>? _pushAction;
  List<dynamic>? _carousel;
  String? _category;

  String? getCategory() => _category;

  setCategory(String value) {
    _category = value;
  }

  Map<dynamic, dynamic>? getCustomJson() => _customJson;

  setCustomJson(Map<dynamic, dynamic> value) {
    _customJson = value;
  }

  Map<dynamic, dynamic>? getPushAction() => _pushAction;

  setPushAction(Map<dynamic, dynamic> value) {
    _pushAction = value;
  }

  List<dynamic>? getCarousel() => _carousel;

  setCarousel(List<dynamic> value) {
    _carousel = value;
  }

  String? getTitle() => _title;

  setTitle(String value) {
    _title = value;
  }

  String? getPopUpExpirationTime() => _expireTime;

  setPopUpExpirationTime(String value) {
    _expireTime = value;
  }

  String? getMediaAttachmentUrl() => _mediaAttachmentURL;

  setTMediaAttachmentUrl(String value) {
    _mediaAttachmentURL = value;
  }

  String? getSubtitle() => _subtitle;

  List<dynamic>? getCategories() => _categories;

  setCategories(List<dynamic> value) {
    _categories = value;
  }

  List<NetmeraInteractiveAction>? getInteractiveActions() =>
      _interactiveActions;

  setInteractiveActions(List<NetmeraInteractiveAction> value) {
    _interactiveActions = value;
  }

  String? getExternalId() => _externalId;

  setExternalId(String value) {
    _externalId = value;
  }

  String? getDeepLink() => _actionDeepLinkUrl;

  setDeepLink(String value) {
    _actionDeepLinkUrl = value;
  }

  String? getWebPage() => _actionWebPageUrl;

  setWebPage(String value) {
    _actionWebPageUrl = value;
  }

  int? getInboxStatus() => _inboxStatus;

  setInboxStatus(int value) {
    _inboxStatus = value;
  }

  String? getSendDate() => _sendDate;

  setSendDate(String value) {
    _sendDate = value;
  }

  String? getPushInstanceId() => _pushInstanceId;

  setPushInstanceId(String value) {
    _pushInstanceId = value;
  }

  String? getPushId() => _pushId;

  setPushId(String value) {
    _pushId = value;
  }

  int? getPushType() => _pushType;

  setPushType(int value) {
    _pushType = value;
  }

  String? getBody() => _body;

  setBody(String value) {
    _body = value;
  }

  setSubtitle(String value) {
    _subtitle = value;
  }

  static fromJson(Map<dynamic, dynamic> json) {
    NetmeraPushInbox inbox = new NetmeraPushInbox();
    inbox._title = json['title'];
    inbox._subtitle = json['subtitle'];
    inbox._body = json['body'];
    inbox._pushType = json['pushType'];
    inbox._pushId = json['pushId'];
    inbox._pushInstanceId = json['pushInstanceId'];
    inbox._sendDate = json['sendDate'];
    inbox._inboxStatus = json['inboxStatus'];
    inbox._actionDeepLinkUrl = json['action_deeplink_url'];
    inbox._actionWebPageUrl = json['action_webpage_url'];
    inbox._externalId = json['externalId'];
    inbox._customJson = json['customJson'];
    inbox._pushAction = json['pushAction'];
    inbox._carousel = json['carousel'];
    inbox._mediaAttachmentURL = json['mediaAttachmentURL'];
    inbox._category = json['category'];
    inbox._categories = json['categories'];
    inbox._expireTime = json['expireTime'];
    if (json['interactiveActions'] != null) {
      inbox._interactiveActions =
          List.from(jsonDecode(json['interactiveActions']))
              .map((model) => NetmeraInteractiveAction.fromJson(model))
              .toList(); //todo check flutter 2.0
    }

    return inbox;
  }

  Map<String, dynamic> toJson() => {
        'title': _title,
        'subtitle': _subtitle,
        'body': _body,
        'pushType': _pushType,
        'pushId': _pushId,
        'pushInstanceId': _pushInstanceId,
        'sendDate': _sendDate,
        'inboxStatus': _inboxStatus,
        'action_deeplink_url': _actionDeepLinkUrl,
        'action_webpage_url': _actionWebPageUrl,
        'externalId': _externalId,
        'customJson': _customJson,
        'pushAction': _pushAction,
        'carousel': _carousel,
        'mediaAttachmentURL': _mediaAttachmentURL,
        'category': _category,
        'categories': _categories,
        'interactiveActions': _interactiveActions,
        'expireTime': _expireTime
      };
}
